@@ -9,7 +9,7 @@
 from init_helpers.annotation import note, try_extract_type_notes
 from init_helpers.conditional_insert import conditional_set, conditional_append, conditional_add
 from init_helpers.conditional_insert import set_if, append_if, add_if
-from init_helpers.custom_json import ReprInDumps, custom_dumps, read_json_file_by_path
+from init_helpers.custom_json import ReprInDumps, custom_dumps, read_json_file_by_path, Jsonable
 from init_helpers.dataclass_protocol import DataclassProtocol
 from init_helpers.dict_to_dataclass import dict_to_dataclass, get_converter, write_to_dict_or_raise, convert
 from init_helpers.eval_forward_refs import eval_forward_refs_in_local_dataclasses, get_evaled_dataclass_fields
